The data frame activities defines activities that support data collection in some essential way, either directly or indirectly.

Format

Data frame.

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

Details

Several attributes are given and not all categories are further used by the REP-workflow. The field activities are used in the REP to create the designed sampling unit calendar of field activity groups (fag_stratum_grts_calendar). Several other activities are used in fieldwork optimization steps outside of the REP.

See also