The data frame activity_sequences defines the available activity sequences. An activity sequence is a set of activities (from activities) that are tied together at location level for a specific scheme in a module, with a specific chronological order and a specific intent.

Format

Data frame.

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

Details

The intent of an activity sequence is to be seen in the context of a scheme in a module, and relates to data collection for one or more variables. An activity sequence may be used by different schemes, and a single scheme may combine more than one, since multiple variables are determined by a single scheme. Also, different activity sequences may apply to the same scheme depending on the module.

Some activities in an activity sequence may have different panel designs, due to the nature of the activity or other requirements or restrictions, so the frequency of some activities may be higher but the overall chronology remains in place.

Note

Currently, activity_sequences is also the place where the activity groups are inherently defined (i.e. which activities they are composed of), although this is no logical place for this. The plan is to isolate that aspect so that activity_sequences can be replaced by an object activity_group_sequences.

See also