The data frame domain_type_nunits contains the spatial population size of each type in each domain, without taking into account scheme-specific spatial restrictions.

Format

Data frame.

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

Details

domain_type_nunits is derived from domain_stratum_nunits by simply aggregating strata that belong to the same type; see its documentation for more background, as well as submod_dom_scheme_ssf_stratum_nunits.

See also