The sf object domains defines code, names and geometry of each geospatial domain that is targeted by a module (see module_domains).

Format

A simple feature collection of type MULTIPOLYGON.

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

Details

With the term 'domain' we always refer to a geospatial domain listed in this object.

See also