The data frame mod_scheme_variableset_mainfieldactivity contains just the main data collection methods from mod_scheme_vars that are field activities, which are now renamed as 'main field activities'. In addition, it contains the main field activities for MHQ schemes.

Format

Data frame.

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

Details

Note that MHQ schemes are not considered in mod_scheme_vars, which is focused on MNE, but their associated activities are supported by activities and activity_sequences.

Note that the terms 'main data collection method' and 'main field activity' are to be understood from the viewpoint of a variable (variable set) in a module:scheme combination; it is not about the 'main method' of the module:scheme combination. In consequence, multiple 'main field activities' can be linked to a module:scheme combination, and they may come from target variables and other variables as well.

Restriction by domains and sampling frames

This object has been further restricted by module_domain_schemes. This means that the current spatial distribution of target populations of the module's schemes within the module's domain(s) is taken into account, using the scheme's spatial sampling frame. When the domains of a module represent a relatively small area, it is possible:

  • for target populations: that some types (that were initially targeted by the module) are not present in that area and consequently dropped from the module's target populations

  • for schemes: that some schemes targeted by the module are not applicable, i.e. when no types of its target population are present in that area

Also, note that for MHQ schemes, module_domain_schemes only considers – on a domain basis – the schemes with sampling approaches, not the census approaches, and this also leads to a further restriction.

See also