The data frame mod_scheme_vars defines variables (usually environmental variables) per module and (MNE) scheme, as well the associated measurement variable (if the variable is directly based on measurements). Also, the target site factor is given for which the variable serves a role in the module and scheme. Further, multiple attributes are given that characterize the variable in the context of the module and the scheme.

Format

Data frame.

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

Details

The measurement variable may be different from the environmental variable when the latter is defined by aggregating multiple measurements to obtain one value for the spatiotemporal sampling unit.

In the context of a module and (especially) a scheme, variables can be qualified as 'target variables' (aka primary environmental variables), 'explanatory variables' or 'quality control variables'. A variable sometimes belongs to more than one of these categories.

XXXXXX Omit once columns have been described: XXXXXXXXXXXXXXXX The main data collection method represents the activity that is considered most essential (most specific) for the data collection in the spatial or spatiotemporal sampling unit. It must be an activity from the activities object.

See also