The data frame n2khab_strata defines the stratum levels available in the stratum column of the spatial sampling frames (see sp_samplingframes, scheme_sampling_frame). Also, the data frame defines the link between type and stratum.

Format

Data frame.

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

Details

The strata are used in spatial sampling and inference. They are either a type or a subdivision thereoff. The latter applies to watersurface types (type regex "^31|^2190_a") and to type 8310.

See also