The data frame scheme_moco_ps_spsubset_targetfag_stratum_sppost_spsamples_calendar represents the (planned) spatiotemporal samples per scheme x module combo x panel set x spatial poststratum.

Format

Data frame.

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

Details

scheme_moco_ps_spsubset_targetfag_stratum_sppost_spsamples_calendar is the subset of scheme_moco_ps_spsubset_fag_stratum_sppost_spsamples_calendar that only contains the target field activity groups (based on mod_scheme_targetfieldactivity). The corresponding panel labels have been simplified in the targetpanel column: 'targetpanels' are the panels of target FAGs, cf. scheme_ps_target_paneldesign.

The spatiotemporal samples are not further used in the REP workflow, but the object can be useful to add some attributes to FAG occasions from fag_stratum_grts_calendar, such as the involved scheme, module combo, panel set and targetpanel. This has been done in the 'code snippets' (e.g. fieldwork_shortterm_prioritization_by_stratum).

See also