The data frame scheme_moco_ps_stratum_sppost_spsamples_spares contains the spatial samples plus the spare units per stratum, for each scheme x panel set x module combo.

Format

Data frame.

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

Details

scheme_moco_ps_stratum_sppost_spsamples_spares is the first result of the spatial sampling procedure that distinguishes the spatial poststrata.

Note that spatial samples typically overlap between schemes, i.e. where the scheme's target populations overlap.

Sample column notes

XXXXXX Omit once columns have been described: XXXXXXXXXXXXXXXX

  • grts_address and stratum together identify the spatial sampling unit. See further in fieldwork_shortterm_prioritization_by_stratum.

  • The spatial poststratum (sp_poststratum) serves to add spare units and to apply the revisit design (notably the panel membership design): it is based on the domain overlaps between modules in a module combo for a specific stratum in a scheme x panel set, so it is not an overall predetermined classification but a 'classification as needed'. It takes values of domains as well as the complement of overlapped smaller domains by using the suffix '_remainder', e.g. 'Flanders_remainder'. Don't use sp_poststratum to just characterize a GRTS address. If you need a fixed spatial partitioning across strata and schemes, make a join with domainpart_grts_n2khab, where the 'domain partition' only represents areas that are mutually exclusive in space.

See also