The data frame sp_samplingframe_domain is no more than the data frame sp_samplingframes where each sampling frame has been extended with a domain column. Since domains can overlap, joining the spatial population units with the applicable domain(s) has generated duplicates of many units in this object.

Format

Data frame.

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

See also