The data frame submodules defines the submodules of each module. Each submodule is strictly linked to a set of schemes and associated target populations.

Format

Data frame.

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

Details

The submodule name is only unique within a module. Each module has at least a single submodule, typically the submodule 'main'. With only a single submodule 'main' in place, the role of a submodule is trivial.

More submodules can exist in the same module, and these open the possibility to differentially extend the spatial sample of the main submodule. This means that some strata get extra locations than others, and other strata may be neglected in the submodule, meaning that the scheme + target population set may be smaller than the one at the module level. Put more generally, submodules differ in their scheme + target population set but together they represent the scheme + target population set of the module.

Submodules of the same module serve to contribute a part of the spatial sample size of each stratum in a module x scheme x domain, via submodule_domain_scheme_ps_designattr.

See also