R/repdata_defining_vars_acts.R
activities.RdThe data frame activities defines activities that support data collection
in some essential way, either directly or indirectly.
Data frame.
The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.
Several attributes are given and not all categories are further used by the
REP-workflow. The field activities are used in the REP to create the designed
sampling unit calendar of field activity groups
(fag_stratum_grts_calendar). Several other activities are used in
fieldwork optimization steps outside of the REP.
Other defining REP objects:
activity_sequences,
domains,
mod_scheme_vars,
module_domains,
modules,
n2khab_strata,
scheme_sampling_frame,
scheme_targetpop_sets,
sp_samplingframes,
submodules