R/repdata_popsizes.R
domain_stratum_nunits.RdThe data frame domain_stratum_nunits contains the spatial population size of each
stratum in each domain, without taking into account scheme-specific spatial
restrictions.
Data frame.
The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.
domain_stratum_nunits is based on the collapsed & phab-corrected base sampling frame
(stratum_grts_n2khab_phabcorrected_no_replacements). Hence it is
scheme-agnostic, while some schemes need a more restricted sampling frame
(see sp_samplingframes). For the final population sizes at submodule x
domain x scheme level, see submod_dom_scheme_ssf_stratum_nunits.
Other REP objects about spatial population size:
domain_type_nunits,
submod_dom_scheme_ssf_stratum_nunits,
submodule_domain_scheme_stratumstats,
submodule_domain_scheme_typestats