The sf object domains defines code, names and geometry of each geospatial
domain that is targeted by a module (see module_domains).
A simple feature collection of type MULTIPOLYGON.
The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.
With the term 'domain' we always refer to a geospatial domain listed in this object.
Other defining REP objects:
activities,
activity_sequences,
mod_scheme_vars,
module_domains,
modules,
n2khab_strata,
scheme_sampling_frame,
scheme_targetpop_sets,
sp_samplingframes,
submodules