The data frame fag_stratum_grts_calendar represents the designed sampling
unit calendar – across schemes – of the distinguished field activity groups
(FAGs). It has unique combinations of stratum, grts_address,
date_interval and field_activity_group.
Data frame.
The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.
fag_stratum_grts_calendar is derived from the scheme-specific FAG calendars
(object scheme_moco_ps_spsubset_fag_stratum_sppost_spsamples_calendar) by
eliminating spatiotemporal duplication and taking into account the highest
required FAG frequency across schemes.
fag_stratum_grts_calendar can have extensions included, i.e. appended FAG
occasions according to older fag_stratum_grts_calendar versions, i.e. from
older REP versions. This subset can be seen by inspecting the object
cal_old_continuation. Some of these rows may even concern spatial sampling
units that are missing from the current spatiotemporal samples,
but for which selected field activity groups (FAGs) and occasions have been
retained. The appended FAG occasions can only be applied in reality if the
preceding FAG occasions on which they depend (not included) have already
taken place, i.e. in the context of a previous REP release.