R/snippetdata.R
fieldwork_shortterm_prioritization_by_stratum.RdThe data frame fieldwork_shortterm_prioritization_by_stratum is an extract
from fag_stratum_grts_calendar and has extra attribute columns. The aim
is to provide the input needed for shortterm fieldwork planning and
prioritization, based on the designed revisit pattern of the most important
field activities. For that reason, it has the priority and wait_xxx
columns.
Data frame.
The code snippets file, which creates objects derived from REP objects. See https://github.com/inbo/n2khab-mne-monitoring/blob/main/020_fieldwork_organization/code_snippets.R.
The is_forest, in_mhq_samples and last_type_assessment_in_field columns
are given because they drive subsampling locations in cell-based sampling
units.
The dates of early FAG occasions that match "LOCEVAL|SAMPLPOINT" may have
been edited (postponed) compared to fag_stratum_grts_calendar.
The object typically focuses on a shorter time frame, e.g. one year, but it
may also contain some future FAG occasions if in reality it is allowed to
execute them earlier or if more preceding occasions can be added to them. An
example (since tags rep_0.14.0 and fieldworgsnippets_0.12.0_poc_0.14.0)
is to include all first FAG occasions per sampling unit that match
"INST|LEVREAD|SPATPOSIT" in groundwater schemes: INST & SPATPOSIT then
represent FAGs that can be executed earlier than planned, and the LEVREAD
occasions can be used as a reference to add more preceding occasions that
comply with the revisit pattern of this FAG in a specific sampling unit.
Beware that fag_stratum_grts_calendar may contain appended FAG occasions
according to older versions, i.e. from older REP versions, and that this is
consequently present in fieldwork_shortterm_prioritization_by_stratum. See
fag_stratum_grts_calendar for more information.
scheme_ps_targetpanels_servedFactor. A concatenation of
"{scheme}:PS{panel set number}{targetpanel}" strings, separated by " | " in case more than one targetpanel applies. It represents the different
schemes (with the associated panel set and targetpanel of the sampling
unit) that require this field activity group in the specified spatial
sampling unit to happen in the specified date interval as it cannot be
delayed with regard to the data collection for these schemes. Compare with
schemes_served_all. For field activity group (FAG) occasions and spatial
sampling units that do not correspond to the current spatiotemporal
samples (see scheme_ps_oldtargetpanels_served), the value of
scheme_ps_oldtargetpanels_served is used instead. This is done to avoid
missing values in derived objects or overviews.
schemes_served_allFactor. A concatenation of schemes, separated by
"|", that will make use of this scheduled field activity group (FAG) in
the specified spatial sampling unit. It includes the schemes mentioned in
scheme_ps_targetpanels_served but it can have more: in other schemes this
FAG would have been scheduled at a later time, but they can and will use
this FAG occasion instead.
nr_schemes_currentInteger. The number of schemes that have scheduled this field activity group in the specified spatial sampling unit in the specified date interval.
nr_schemes_laterInteger. The number of schemes that originally scheduled this field activity group in the specified spatial sampling unit in a later date interval, but that will be using this occasion instead.
stratumFactor. A type or a subdivision thereof, used in the
stratified sampling design and inference. Defined by the n2khab_strata
data frame.
grts_join_methodFactor. The method that has served to assign a GRTS address to the sampling unit.
sample_support_codeFactor. Code that reflects the sample support, i.e. geometric properties (size, shape, orientation) that define the sampling unit. The sample support depends on the type (hence on stratum).
grts_addressInteger. The GRTS address from the
GRTSmaster_habitats data source
that has been drawn when creating the sample. grts_address and
stratum together identify the spatial sampling unit.
grts_address_finalInteger. The GRTS address from the
GRTSmaster_habitats data source
that has been used as a local replacement for grts_address, given the
stratum. Its role is to point at the final location for data collection.
grts_address_final remains tied to grts_address and stratum, that
identify the spatial sampling unit. (grts_address_final can also be
regarded as a secondary sampling unit within a larger primary sampling unit
determined by grts_address and stratum.)
domain_partFactor. The domain partition to which the spatial sampling unit belongs.
is_forestLogical. Does the stratum correspond to a forest type?
Forest types are defined using the regex "^9|^2180|^rbbppm".
in_mhq_samplesLogical. Is the sampling unit also a member of a spatial sample of MHQ (at the Flemish level)?
last_type_assessment_in_fieldLogical. Did the sampling unit get a field assessment in the past as part of MHQ (at the Flemish level)?
last_type_assessmentDate. Latest available MHQ field assessment date for the sampling unit in MHQ (at the Flemish level).
last_inaccessibleFactor. The degree of inaccessibility during the
latest available MHQ field assessment for the sampling unit (MHQ at the
Flemish level). Possible factor levels (if not missing) are "short term"
and "long term", reflecting an estimated duration of inaccessibility.
date_startDate. Start of the date interval during which the field activity group is scheduled in the spatial sampling unit.
date_endDate. End of the date interval during which the field activity group is scheduled in the spatial sampling unit.
date_intervalInterval. The date interval during which the field activity group is scheduled in the spatial sampling unit.
field_activity_groupFactor. A defined group of field activities. Many field activity groups consist of just one field activity.
rankInteger. A rank number representing the order of execution relative to other field activity groups that are scheduled in the same date interval, for the same spatial sampling unit. This rank has originally been defined within an activity sequence that was assigned to the spatial sampling unit in the context of a specific module and scheme.
matching_occasionFactor. If present, the value is common between at
least two rows (FAG occasions). FAG occasions marked in this way as a
'matching occasion' involve the same FAG at the same GRTS address but
across different lentic strata (types). A matching date interval may also
be a requirement, depending on the FAG. Matching FAG occasions effectively
represent a single FAG occasion in the field, even though data collection
may be still be stratum-specific. The value is composed as
<field_activity_group>_<grts_address_final>_[<formatted date interval>].
The date interval is missing for FAGs that match regex
"INST|LEVREAD|SPATPOSIT", as they don't require the same date interval
order to be 'matching'.
scheme_ps_oldtargetpanels_servedFactor. A string formatted as and
with a meaning similar to scheme_ps_targetpanels_served but according to
older versions of the REP. Most rows have a missing value, but rows with
a value refer to a part of fag_stratum_grts_calendar from an older REP
version that has been appended to the current version. Some of these rows
may even concern spatial sampling units that are missing from the current spatiotemporal samples,
for which selected field activity groups (FAGs) and occasions have been
retained. The appended FAG occasions can only be applied in reality if the
preceding FAG occasions on which they depend (not included) have already
taken place, i.e. in the context of a previous release of the short-term
fieldwork calendar.
priorityInteger. A rank number representing the priority of the scheduled field activity group for the specified spatial sampling unit.
wait_anyLogical. Should the scheduled field activity group in the
specified spatial sampling unit be put on hold? This column is TRUE if
any of the other wait columns is TRUE.
wait_watersurfaceLogical. Should the scheduled field activity group
in the specified spatial sampling unit be put on hold because the sampling
unit is a watersurface type? The value may also depend on the schemes in
schemes_served_all.
wait_3260Logical. Should the scheduled field activity group in the
specified spatial sampling unit be put on hold because the sampling unit
belongs to type 3260?
wait_7220Logical. Should the scheduled field activity group in the
specified spatial sampling unit be put on hold because the sampling unit
belongs to type 7220?
wait_floatingLogical. Should the scheduled field activity group in
the specified spatial sampling unit be put on hold because the sampling
unit belongs to a floating (fen) type? Currently this is defined as type
7140_mrd.
wait_mhqLogical. Should the scheduled field activity group in the
specified spatial sampling unit be put on hold because in the considered
date interval (year) the field activity group is only needed for a MHQ
scheme? (The latter is seen in the value of
scheme_ps_targetpanels_served.)
wait_obsolete_typesLogical. Should the scheduled field activity group in the specified spatial sampling unit be put on hold because the type will be obsoleted and this makes this FAG occasion in this panel set irrelevant?