R/repdata_defining_vars_acts.R
mod_scheme_field_activity.RdThe data frame mod_scheme_field_activity contains all field activities and
associated field activity groups (FAGs) for each activity sequence in a
module x scheme x spatial subset.
Data frame.
The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.
mod_scheme_field_activity (indirectly) builds on
mod_scheme_variableset_mainfieldactivity, activity_sequences and
properties of the target populations.
XXXXXX Omit once columns have been described: XXXXXXXXXXXXXXXX The
spatial subset is used in multiple objects and currently only concerns the
distinction between aquatic and terrestrial strata (column
in_aquatic_subset). It is relevant to determine the applicable activity
sequence (i.e. for involved field activity groups).
This object has been further restricted by module_domain_schemes. This
means that the current spatial distribution of target populations of the
module's schemes within the module's domain(s) is taken into account,
using the scheme's spatial sampling frame. When the domains of a module
represent a relatively small area, it is possible:
for target populations: that some types (that were initially targeted by the module) are not present in that area and consequently dropped from the module's target populations
for schemes: that some schemes targeted by the module are not applicable, i.e. when no types of its target population are present in that area
Also, note that for MHQ schemes, module_domain_schemes only considers –
on a domain basis – the schemes with sampling approaches, not the census
approaches, and this also leads to a further restriction.
Other derivatives of defining REP objects:
domainpart_grts_n2khab,
mod_scheme_targetfieldactivity,
mod_scheme_variableset_mainfieldactivity,
module_domain_schemes,
module_schemes,
module_targetpops,
schemes,
sp_samplingframe_domain,
targetpops,
targetpops_strata