R/repdata_design_attribs.R
mod_scheme_ps_fag_paneldesign.RdThe data frame mod_scheme_ps_fag_paneldesign defines the panel design of
each field activity group per module x scheme x panel set x spatial subset.
Data frame.
The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.
mod_scheme_ps_fag_paneldesign (indirectly) uses
mod_scheme_field_activity as its base, but with collapsed activity
sequences: field activity groups shared among multiple activity sequences (in
the same module, scheme and spatial subset) appear only once.
XXXXXX Omit once columns have been described: XXXXXXXXXXXXXXXX The
spatial subset is used in multiple objects and currently only concerns the
distinction between aquatic and terrestrial strata (column
in_aquatic_subset). It is relevant to determine the applicable activity
sequence (i.e. for involved field activity groups).
Other REP objects with design attributes:
mod_scheme_yrs_moco_ps,
module_domain_scheme_ps_stratum_sample_size,
scheme_ps_target_paneldesign,
scheme_ps_variableset_paneldesign,
submodule_domain_scheme_ps_designattr