R/repdata_defining_basic.R
module_domain_schemes.RdThe data frame module_domain_schemes lists the schemes that apply to each
domain in each module, according to the presence of strata in domains, hence
according to the sampling frames.
Data frame.
The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.
For MHQ schemes, module_domain_schemes only considers – on a domain basis –
the schemes with sampling approaches, not the census approaches, and this
also leads to a further restriction.
module_domain_schemes is derived from
submod_dom_scheme_ssf_stratum_nunits, which is in turn derived from
scheme_sampling_frame, sp_samplingframe_domain and a few other
objects (see there).
module_domain_schemes has been used to limit several module:scheme objects
that had been made before, such as module_schemes, module_targetpops,
mod_scheme_variableset_mainfieldactivity, mod_scheme_field_activity,
mod_scheme_ps_fag_paneldesign.
Other derivatives of defining REP objects:
domainpart_grts_n2khab,
mod_scheme_field_activity,
mod_scheme_targetfieldactivity,
mod_scheme_variableset_mainfieldactivity,
module_schemes,
module_targetpops,
schemes,
sp_samplingframe_domain,
targetpops,
targetpops_strata