R/repdata_design_attribs.R
submodule_domain_scheme_ps_designattr.RdThe data frame submodule_domain_scheme_ps_designattr contains the
spatiotemporal design attributes per submodule x domain x scheme x panel set.
Data frame.
The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.
submodule_domain_scheme_ps_designattr is the last stage in the REP workflow
where submodules are being distinguished; in determining stratum level sample
sizes (see module_domain_scheme_ps_stratum_sample_size) the sample sizes
of the submodules of each module are taken together (see submodules).
XXXXXX Omit once columns have been described: XXXXXXXXXXXXXXXX The
spatial sample sizes refer to the submodule x domain x scheme x panel set
level (sp_sample_size_all_panels) and to the level of a single
(generalized) type (sp_sample_size_all_panels_type) within submodule x
domain x scheme x panel set, respectively.
Other REP objects with design attributes:
mod_scheme_ps_fag_paneldesign,
mod_scheme_yrs_moco_ps,
module_domain_scheme_ps_stratum_sample_size,
scheme_ps_target_paneldesign,
scheme_ps_variableset_paneldesign